<?php
class TipoImovelCaracteristica {
    private $con;
 
    public function __construct() {
        $this->con = new Conexao();
    }   
 
    public function save($dados) {
        if(empty($dados['id']))
            $this->insert($dados);
        else
            $this->update($dados);
    }
 
    private function insert($dados) {

		$query = "insert into caracteristica_cat ".
				 "(cat_nome, cat_tipo, cat_default, cat_indice, cat_icone) ".
				 "VALUES ".
				 "(:cat_nome, :cat_tipo, :cat_default, :cat_indice, :cat_icone) ";
				
        $conexao = $this->con->connect();
		$stmt = $conexao->prepare($query);
        $stmt->bindParam(':cat_nome', $dados['cat_nome']);
		$stmt->bindParam(':cat_tipo', $dados['cat_tipo']);
		$stmt->bindParam(':cat_default', $dados['cat_default']);
		$stmt->bindParam(':cat_indice', $dados['cat_indice']);
		$stmt->bindParam(':cat_icone', $dados['cat_icone']);
        $stmt->execute();
		return $conexao->lastInsertId();		
    }
 
    private function update($dados) {
		$query = "update caracteristica_cat set ".
				 "cat_nome = :cat_nome, cat_tipo = :cat_tipo, ".
				 "cat_default = :cat_default, cat_indice = :cat_indice, cat_icone = :cat_icone ".
				 "where cat_codigo = :cat_codigo";

		$stmt = $this->con->connect()->prepare($query);
        $stmt->bindParam(':cat_nome', $dados['cat_nome']);
		$stmt->bindParam(':cat_tipo', $dados['cat_tipo']);
		$stmt->bindParam(':cat_default', $dados['cat_default']);
		$stmt->bindParam(':cat_indice', $dados['cat_indice']);
		$stmt->bindParam(':cat_icone', $dados['cat_icone']);
        $stmt->bindParam(':cat_codigo', $dados['cat_codigo']);
        $stmt->execute();
    }
 
    public function delete($id) {
		$query = "delete from caracteristica_cat ".
				 "where cat_codigo = :cat_codigo";

		$stmt = $this->con->connect()->prepare($query);
        $stmt->bindParam(':cat_codigo', $id);
        $stmt->execute();
    }

    public function selecionaTipoImovelCaracteristica($id) {
        $stmt   = $this->con->connect()->prepare("select * from caracteristica_cat where cat_codigo = :id");
        $stmt->bindParam(':id', $id);
        $stmt->execute();
        $resultado = $stmt->fetch();
        return $resultado;
    }
 
    public function selecionaTipoImovelCaracteristicas($id) {
        $stmt   = $this->con->connect()->prepare("select cat_nome, cat_codigo, ifnull(tpc_cat_codigo, 0) as marcado from caracteristica_cat left outer join tpicat_tpc on cat_codigo = tpc_cat_codigo and tpc_tpi_codigo = :tpc_tpi_codigo");
		$stmt->bindParam('tpc_tpi_codigo', $id);
        $stmt->execute();
        $resultado = $stmt->fetchAll();
        return $resultado;
    }

    public function selecionaTipoImovelCaracteristicasDados($id, $idtpimovel) {
        $stmt   = $this->con->connect()->prepare(
			"select ".
			"	cat_nome, cat_codigo, cat_tipo, imc_valor ".
			"from ".
			"	caracteristica_cat inner join ".
			"	tpicat_tpc on cat_codigo = tpc_cat_codigo and tpc_tpi_codigo = :tpc_tpi_codigo left outer join ".
			"	imvcat_imc on cat_codigo = imc_cat_codigo and  imc_imv_codigo = :imc_imv_codigo"
			);
	
		$stmt->bindParam(':imc_imv_codigo', $id);
		$stmt->bindParam(':tpc_tpi_codigo', $idtpimovel);
        $stmt->execute();
        $resultado = $stmt->fetchAll();
        return $resultado;
    }

}