<?php
class Noticia {
    private $con;
 
    public function __construct() {
        $this->con = new Conexao();
    }   
 
    public function save($dados) {
        if(empty($dados['id']))
            $this->insert($dados);
        else
            $this->update($dados);
    }
 
    private function insert($dados) {

		$query = "insert into noticia_not ".
				 "(not_titulo, not_chamada, not_conteudo, not_imagem, not_ordem, not_publicado, not_posicao, not_txtadicional, not_icone) ".
				 "VALUES ".
				 "(:not_titulo, :not_chamada, :not_conteudo, :not_imagem, :not_ordem, :not_publicado, :not_posicao, :not_txtadicional, :not_icone) ";
				
        $conexao = $this->con->connect();
		$stmt = $conexao->prepare($query);       
		$stmt->bindParam(':not_titulo', $dados['not_titulo']);
		$stmt->bindParam(':not_conteudo', $dados['not_conteudo']);
		$stmt->bindParam(':not_chamada', $dados['not_chamada']);
		$stmt->bindParam(':not_imagem', $dados['not_imagem']);
		$stmt->bindParam(':not_ordem', $dados['not_ordem']);
		$stmt->bindParam(':not_publicado', $dados['not_publicado']);
        $stmt->bindParam(':not_posicao', $dados['not_posicao']);
		$stmt->bindParam(':not_txtadicional', $dados['not_txtadicional']);
		$stmt->bindParam(':not_icone', $dados['not_icone']);
		$stmt->execute();
		return $conexao->lastInsertId();		
    }
 
    private function update($dados) {
		$query = "update noticia_not set ".
				 "not_titulo = :not_titulo, not_chamada = :not_chamada, not_conteudo = :not_conteudo, not_imagem = :not_imagem, not_ordem = :not_ordem, not_publicado = :not_publicado, not_posicao = :not_posicao, not_txtadicional = :not_txtadicional, not_icone = :not_icone ".
				 "where not_codigo = :not_codigo";

		$stmt = $this->con->connect()->prepare($query);
		$stmt->bindParam(':not_titulo', $dados['not_titulo']);
		$stmt->bindParam(':not_conteudo', $dados['not_conteudo']);
		$stmt->bindParam(':not_chamada', $dados['not_chamada']);
		$stmt->bindParam(':not_imagem', $dados['not_imagem']);
		$stmt->bindParam(':not_ordem', $dados['not_ordem']);
		$stmt->bindParam(':not_publicado', $dados['not_publicado']);
        $stmt->bindParam(':not_posicao', $dados['not_posicao']);
		$stmt->bindParam(':not_txtadicional', $dados['not_txtadicional']);
		$stmt->bindParam(':not_icone', $dados['not_icone']);
        $stmt->bindParam(':not_codigo', $dados['not_codigo']);
        $stmt->execute();
    }
 
    public function delete($id) {
		$query = "delete from noticia_not ".
				 "where not_codigo = :not_codigo";

		$stmt = $this->con->connect()->prepare($query);
        $stmt->bindParam(':not_codigo', $id);
        $stmt->execute();
    }

    public function selecionaNoticia($id) {
        $stmt   = $this->con->connect()->prepare("select * from noticia_not where not_codigo = :id");
        $stmt->bindParam(':id', $id);
        $stmt->execute();
        $resultado = $stmt->fetch();
        return $resultado;
    }
 
    public function selecionaNoticias() {
        $stmt   = $this->con->connect()->prepare("select * from noticia_not order by not_ordem");
        $stmt->execute();
        $resultado = $stmt->fetchAll();
        return $resultado;
    }

    public function selecionaNoticiaByPosition($id) {
        $stmt   = $this->con->connect()->prepare("select * from noticia_not where not_posicao = :id");
        $stmt->bindParam(':id', $id);
        $stmt->execute();
        $resultado = $stmt->fetch();
        return $resultado;
    }
    public function selecionaNoticiasByPosition($id) {
        $stmt   = $this->con->connect()->prepare("select *, rand() sorteio from noticia_not where not_posicao = :id order by not_ordem, sorteio limit 3");
        $stmt->bindParam(':id', $id);
        $stmt->execute();
        $resultado = $stmt->fetchAll();
        return $resultado;
    }
    public function selecionaNoticiasLinks() {
        $stmt   = $this->con->connect()->prepare("select * from noticia_not where not_posicao in (1, 2, 3, 4, 5, 6, 7) order by not_posicao");
        $stmt->execute();
        $resultado = $stmt->fetchAll();
        return $resultado;
    }
    public function selecionaNoticiasArtigosLinks() {
        $stmt   = $this->con->connect()->prepare("select * from noticia_not where not_posicao = 7 order by not_ordem");
        $stmt->execute();
        $resultado = $stmt->fetchAll();
        return $resultado;
    }
}